const emoji_char_t emoji_chars[]={
{0x23, emoji_property_emoji|emoji_property_emoji_component},
{0x2a, emoji_property_emoji|emoji_property_emoji_component},
{0x30, emoji_property_emoji|emoji_property_emoji_component},
{0x31, emoji_property_emoji|emoji_property_emoji_component},
{0x32, emoji_property_emoji|emoji_property_emoji_component},
{0x33, emoji_property_emoji|emoji_property_emoji_component},
{0x34, emoji_property_emoji|emoji_property_emoji_component},
{0x35, emoji_property_emoji|emoji_property_emoji_component},
{0x36, emoji_property_emoji|emoji_property_emoji_component},
{0x37, emoji_property_emoji|emoji_property_emoji_component},
{0x38, emoji_property_emoji|emoji_property_emoji_component},
{0x39, emoji_property_emoji|emoji_property_emoji_component},
{0xa9, emoji_property_emoji|emoji_property_extended_pictographic},
{0xae, emoji_property_emoji|emoji_property_extended_pictographic},
{0x200d, emoji_property_emoji_component},
{0x203c, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2049, emoji_property_emoji|emoji_property_extended_pictographic},
{0x20e3, emoji_property_emoji_component},
{0x2122, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2139, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2194, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2195, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2196, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2197, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2198, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2199, emoji_property_emoji|emoji_property_extended_pictographic},
{0x21a9, emoji_property_emoji|emoji_property_extended_pictographic},
{0x21aa, emoji_property_emoji|emoji_property_extended_pictographic},
{0x231a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x231b, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x2328, emoji_property_emoji|emoji_property_extended_pictographic},
{0x23cf, emoji_property_emoji|emoji_property_extended_pictographic},
{0x23e9, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x23ea, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x23eb, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x23ec, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x23ed, emoji_property_emoji|emoji_property_extended_pictographic},
{0x23ee, emoji_property_emoji|emoji_property_extended_pictographic},
{0x23ef, emoji_property_emoji|emoji_property_extended_pictographic},
{0x23f0, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x23f1, emoji_property_emoji|emoji_property_extended_pictographic},
{0x23f2, emoji_property_emoji|emoji_property_extended_pictographic},
{0x23f3, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x23f8, emoji_property_emoji|emoji_property_extended_pictographic},
{0x23f9, emoji_property_emoji|emoji_property_extended_pictographic},
{0x23fa, emoji_property_emoji|emoji_property_extended_pictographic},
{0x24c2, emoji_property_emoji|emoji_property_extended_pictographic},
{0x25aa, emoji_property_emoji|emoji_property_extended_pictographic},
{0x25ab, emoji_property_emoji|emoji_property_extended_pictographic},
{0x25b6, emoji_property_emoji|emoji_property_extended_pictographic},
{0x25c0, emoji_property_emoji|emoji_property_extended_pictographic},
{0x25fb, emoji_property_emoji|emoji_property_extended_pictographic},
{0x25fc, emoji_property_emoji|emoji_property_extended_pictographic},
{0x25fd, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x25fe, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x2600, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2601, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2602, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2603, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2604, emoji_property_emoji|emoji_property_extended_pictographic},
{0x260e, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2611, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2614, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x2615, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x2618, emoji_property_emoji|emoji_property_extended_pictographic},
{0x261d, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_extended_pictographic},
{0x2620, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2622, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2623, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2626, emoji_property_emoji|emoji_property_extended_pictographic},
{0x262a, emoji_property_emoji|emoji_property_extended_pictographic},
{0x262e, emoji_property_emoji|emoji_property_extended_pictographic},
{0x262f, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2638, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2639, emoji_property_emoji|emoji_property_extended_pictographic},
{0x263a, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2640, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2642, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2648, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x2649, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x264a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x264b, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x264c, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x264d, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x264e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x264f, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x2650, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x2651, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x2652, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x2653, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x265f, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2660, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2663, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2665, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2666, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2668, emoji_property_emoji|emoji_property_extended_pictographic},
{0x267b, emoji_property_emoji|emoji_property_extended_pictographic},
{0x267e, emoji_property_emoji|emoji_property_extended_pictographic},
{0x267f, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x2692, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2693, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x2694, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2695, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2696, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2697, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2699, emoji_property_emoji|emoji_property_extended_pictographic},
{0x269b, emoji_property_emoji|emoji_property_extended_pictographic},
{0x269c, emoji_property_emoji|emoji_property_extended_pictographic},
{0x26a0, emoji_property_emoji|emoji_property_extended_pictographic},
{0x26a1, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x26a7, emoji_property_emoji|emoji_property_extended_pictographic},
{0x26aa, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x26ab, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x26b0, emoji_property_emoji|emoji_property_extended_pictographic},
{0x26b1, emoji_property_emoji|emoji_property_extended_pictographic},
{0x26bd, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x26be, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x26c4, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x26c5, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x26c8, emoji_property_emoji|emoji_property_extended_pictographic},
{0x26ce, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x26cf, emoji_property_emoji|emoji_property_extended_pictographic},
{0x26d1, emoji_property_emoji|emoji_property_extended_pictographic},
{0x26d3, emoji_property_emoji|emoji_property_extended_pictographic},
{0x26d4, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x26e9, emoji_property_emoji|emoji_property_extended_pictographic},
{0x26ea, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x26f0, emoji_property_emoji|emoji_property_extended_pictographic},
{0x26f1, emoji_property_emoji|emoji_property_extended_pictographic},
{0x26f2, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x26f3, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x26f4, emoji_property_emoji|emoji_property_extended_pictographic},
{0x26f5, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x26f7, emoji_property_emoji|emoji_property_extended_pictographic},
{0x26f8, emoji_property_emoji|emoji_property_extended_pictographic},
{0x26f9, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_extended_pictographic},
{0x26fa, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x26fd, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x2702, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2705, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x2708, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2709, emoji_property_emoji|emoji_property_extended_pictographic},
{0x270a, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x270b, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x270c, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_extended_pictographic},
{0x270d, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_extended_pictographic},
{0x270f, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2712, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2714, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2716, emoji_property_emoji|emoji_property_extended_pictographic},
{0x271d, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2721, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2728, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x2733, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2734, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2744, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2747, emoji_property_emoji|emoji_property_extended_pictographic},
{0x274c, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x274e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x2753, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x2754, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x2755, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x2757, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x2763, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2764, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2795, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x2796, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x2797, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x27a1, emoji_property_emoji|emoji_property_extended_pictographic},
{0x27b0, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x27bf, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x2934, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2935, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2b05, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2b06, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2b07, emoji_property_emoji|emoji_property_extended_pictographic},
{0x2b1b, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x2b1c, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x2b50, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x2b55, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x3030, emoji_property_emoji|emoji_property_extended_pictographic},
{0x303d, emoji_property_emoji|emoji_property_extended_pictographic},
{0x3297, emoji_property_emoji|emoji_property_extended_pictographic},
{0x3299, emoji_property_emoji|emoji_property_extended_pictographic},
{0xfe0f, emoji_property_emoji_component},
{0x1f004, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f0cf, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f170, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f171, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f17e, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f17f, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f18e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f191, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f192, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f193, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f194, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f195, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f196, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f197, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f198, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f199, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f19a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f1e6, emoji_property_emoji|emoji_property_emoji_component|emoji_property_emoji_presentation},
{0x1f1e7, emoji_property_emoji|emoji_property_emoji_component|emoji_property_emoji_presentation},
{0x1f1e8, emoji_property_emoji|emoji_property_emoji_component|emoji_property_emoji_presentation},
{0x1f1e9, emoji_property_emoji|emoji_property_emoji_component|emoji_property_emoji_presentation},
{0x1f1ea, emoji_property_emoji|emoji_property_emoji_component|emoji_property_emoji_presentation},
{0x1f1eb, emoji_property_emoji|emoji_property_emoji_component|emoji_property_emoji_presentation},
{0x1f1ec, emoji_property_emoji|emoji_property_emoji_component|emoji_property_emoji_presentation},
{0x1f1ed, emoji_property_emoji|emoji_property_emoji_component|emoji_property_emoji_presentation},
{0x1f1ee, emoji_property_emoji|emoji_property_emoji_component|emoji_property_emoji_presentation},
{0x1f1ef, emoji_property_emoji|emoji_property_emoji_component|emoji_property_emoji_presentation},
{0x1f1f0, emoji_property_emoji|emoji_property_emoji_component|emoji_property_emoji_presentation},
{0x1f1f1, emoji_property_emoji|emoji_property_emoji_component|emoji_property_emoji_presentation},
{0x1f1f2, emoji_property_emoji|emoji_property_emoji_component|emoji_property_emoji_presentation},
{0x1f1f3, emoji_property_emoji|emoji_property_emoji_component|emoji_property_emoji_presentation},
{0x1f1f4, emoji_property_emoji|emoji_property_emoji_component|emoji_property_emoji_presentation},
{0x1f1f5, emoji_property_emoji|emoji_property_emoji_component|emoji_property_emoji_presentation},
{0x1f1f6, emoji_property_emoji|emoji_property_emoji_component|emoji_property_emoji_presentation},
{0x1f1f7, emoji_property_emoji|emoji_property_emoji_component|emoji_property_emoji_presentation},
{0x1f1f8, emoji_property_emoji|emoji_property_emoji_component|emoji_property_emoji_presentation},
{0x1f1f9, emoji_property_emoji|emoji_property_emoji_component|emoji_property_emoji_presentation},
{0x1f1fa, emoji_property_emoji|emoji_property_emoji_component|emoji_property_emoji_presentation},
{0x1f1fb, emoji_property_emoji|emoji_property_emoji_component|emoji_property_emoji_presentation},
{0x1f1fc, emoji_property_emoji|emoji_property_emoji_component|emoji_property_emoji_presentation},
{0x1f1fd, emoji_property_emoji|emoji_property_emoji_component|emoji_property_emoji_presentation},
{0x1f1fe, emoji_property_emoji|emoji_property_emoji_component|emoji_property_emoji_presentation},
{0x1f1ff, emoji_property_emoji|emoji_property_emoji_component|emoji_property_emoji_presentation},
{0x1f201, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f202, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f21a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f22f, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f232, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f233, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f234, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f235, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f236, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f237, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f238, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f239, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f23a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f250, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f251, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f300, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f301, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f302, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f303, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f304, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f305, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f306, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f307, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f308, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f309, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f30a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f30b, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f30c, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f30d, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f30e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f30f, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f310, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f311, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f312, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f313, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f314, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f315, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f316, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f317, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f318, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f319, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f31a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f31b, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f31c, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f31d, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f31e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f31f, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f320, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f321, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f324, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f325, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f326, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f327, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f328, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f329, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f32a, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f32b, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f32c, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f32d, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f32e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f32f, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f330, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f331, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f332, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f333, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f334, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f335, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f336, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f337, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f338, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f339, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f33a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f33b, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f33c, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f33d, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f33e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f33f, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f340, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f341, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f342, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f343, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f344, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f345, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f346, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f347, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f348, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f349, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f34a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f34b, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f34c, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f34d, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f34e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f34f, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f350, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f351, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f352, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f353, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f354, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f355, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f356, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f357, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f358, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f359, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f35a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f35b, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f35c, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f35d, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f35e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f35f, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f360, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f361, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f362, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f363, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f364, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f365, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f366, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f367, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f368, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f369, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f36a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f36b, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f36c, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f36d, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f36e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f36f, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f370, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f371, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f372, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f373, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f374, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f375, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f376, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f377, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f378, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f379, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f37a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f37b, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f37c, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f37d, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f37e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f37f, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f380, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f381, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f382, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f383, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f384, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f385, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f386, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f387, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f388, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f389, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f38a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f38b, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f38c, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f38d, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f38e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f38f, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f390, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f391, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f392, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f393, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f396, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f397, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f399, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f39a, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f39b, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f39e, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f39f, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f3a0, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3a1, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3a2, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3a3, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3a4, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3a5, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3a6, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3a7, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3a8, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3a9, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3aa, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3ab, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3ac, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3ad, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3ae, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3af, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3b0, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3b1, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3b2, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3b3, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3b4, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3b5, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3b6, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3b7, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3b8, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3b9, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3ba, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3bb, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3bc, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3bd, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3be, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3bf, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3c0, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3c1, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3c2, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3c3, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3c4, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3c5, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3c6, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3c7, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3c8, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3c9, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3ca, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3cb, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_extended_pictographic},
{0x1f3cc, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_extended_pictographic},
{0x1f3cd, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f3ce, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f3cf, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3d0, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3d1, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3d2, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3d3, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3d4, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f3d5, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f3d6, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f3d7, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f3d8, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f3d9, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f3da, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f3db, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f3dc, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f3dd, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f3de, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f3df, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f3e0, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3e1, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3e2, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3e3, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3e4, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3e5, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3e6, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3e7, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3e8, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3e9, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3ea, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3eb, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3ec, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3ed, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3ee, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3ef, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3f0, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3f3, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f3f4, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3f5, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f3f7, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f3f8, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3f9, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3fa, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f3fb, emoji_property_emoji|emoji_property_emoji_component|emoji_property_emoji_modifier|emoji_property_emoji_presentation},
{0x1f3fc, emoji_property_emoji|emoji_property_emoji_component|emoji_property_emoji_modifier|emoji_property_emoji_presentation},
{0x1f3fd, emoji_property_emoji|emoji_property_emoji_component|emoji_property_emoji_modifier|emoji_property_emoji_presentation},
{0x1f3fe, emoji_property_emoji|emoji_property_emoji_component|emoji_property_emoji_modifier|emoji_property_emoji_presentation},
{0x1f3ff, emoji_property_emoji|emoji_property_emoji_component|emoji_property_emoji_modifier|emoji_property_emoji_presentation},
{0x1f400, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f401, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f402, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f403, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f404, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f405, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f406, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f407, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f408, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f409, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f40a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f40b, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f40c, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f40d, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f40e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f40f, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f410, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f411, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f412, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f413, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f414, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f415, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f416, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f417, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f418, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f419, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f41a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f41b, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f41c, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f41d, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f41e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f41f, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f420, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f421, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f422, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f423, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f424, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f425, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f426, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f427, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f428, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f429, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f42a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f42b, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f42c, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f42d, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f42e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f42f, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f430, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f431, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f432, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f433, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f434, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f435, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f436, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f437, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f438, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f439, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f43a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f43b, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f43c, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f43d, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f43e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f43f, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f440, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f441, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f442, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f443, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f444, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f445, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f446, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f447, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f448, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f449, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f44a, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f44b, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f44c, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f44d, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f44e, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f44f, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f450, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f451, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f452, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f453, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f454, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f455, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f456, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f457, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f458, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f459, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f45a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f45b, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f45c, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f45d, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f45e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f45f, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f460, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f461, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f462, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f463, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f464, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f465, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f466, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f467, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f468, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f469, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f46a, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f46b, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f46c, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f46d, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f46e, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f46f, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f470, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f471, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f472, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f473, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f474, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f475, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f476, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f477, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f478, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f479, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f47a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f47b, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f47c, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f47d, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f47e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f47f, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f480, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f481, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f482, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f483, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f484, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f485, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f486, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f487, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f488, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f489, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f48a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f48b, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f48c, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f48d, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f48e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f48f, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f490, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f491, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f492, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f493, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f494, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f495, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f496, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f497, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f498, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f499, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f49a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f49b, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f49c, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f49d, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f49e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f49f, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4a0, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4a1, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4a2, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4a3, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4a4, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4a5, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4a6, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4a7, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4a8, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4a9, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4aa, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4ab, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4ac, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4ad, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4ae, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4af, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4b0, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4b1, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4b2, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4b3, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4b4, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4b5, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4b6, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4b7, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4b8, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4b9, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4ba, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4bb, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4bc, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4bd, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4be, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4bf, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4c0, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4c1, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4c2, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4c3, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4c4, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4c5, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4c6, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4c7, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4c8, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4c9, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4ca, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4cb, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4cc, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4cd, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4ce, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4cf, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4d0, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4d1, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4d2, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4d3, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4d4, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4d5, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4d6, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4d7, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4d8, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4d9, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4da, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4db, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4dc, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4dd, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4de, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4df, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4e0, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4e1, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4e2, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4e3, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4e4, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4e5, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4e6, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4e7, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4e8, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4e9, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4ea, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4eb, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4ec, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4ed, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4ee, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4ef, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4f0, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4f1, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4f2, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4f3, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4f4, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4f5, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4f6, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4f7, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4f8, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4f9, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4fa, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4fb, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4fc, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f4fd, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f4ff, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f500, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f501, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f502, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f503, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f504, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f505, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f506, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f507, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f508, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f509, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f50a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f50b, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f50c, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f50d, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f50e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f50f, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f510, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f511, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f512, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f513, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f514, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f515, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f516, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f517, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f518, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f519, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f51a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f51b, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f51c, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f51d, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f51e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f51f, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f520, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f521, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f522, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f523, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f524, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f525, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f526, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f527, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f528, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f529, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f52a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f52b, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f52c, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f52d, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f52e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f52f, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f530, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f531, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f532, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f533, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f534, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f535, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f536, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f537, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f538, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f539, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f53a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f53b, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f53c, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f53d, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f549, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f54a, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f54b, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f54c, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f54d, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f54e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f550, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f551, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f552, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f553, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f554, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f555, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f556, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f557, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f558, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f559, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f55a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f55b, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f55c, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f55d, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f55e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f55f, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f560, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f561, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f562, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f563, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f564, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f565, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f566, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f567, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f56f, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f570, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f573, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f574, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_extended_pictographic},
{0x1f575, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_extended_pictographic},
{0x1f576, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f577, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f578, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f579, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f57a, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f587, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f58a, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f58b, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f58c, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f58d, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f590, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_extended_pictographic},
{0x1f595, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f596, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f5a4, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f5a5, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f5a8, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f5b1, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f5b2, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f5bc, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f5c2, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f5c3, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f5c4, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f5d1, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f5d2, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f5d3, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f5dc, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f5dd, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f5de, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f5e1, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f5e3, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f5e8, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f5ef, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f5f3, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f5fa, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f5fb, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f5fc, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f5fd, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f5fe, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f5ff, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f600, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f601, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f602, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f603, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f604, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f605, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f606, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f607, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f608, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f609, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f60a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f60b, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f60c, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f60d, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f60e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f60f, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f610, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f611, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f612, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f613, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f614, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f615, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f616, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f617, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f618, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f619, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f61a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f61b, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f61c, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f61d, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f61e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f61f, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f620, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f621, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f622, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f623, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f624, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f625, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f626, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f627, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f628, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f629, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f62a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f62b, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f62c, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f62d, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f62e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f62f, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f630, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f631, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f632, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f633, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f634, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f635, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f636, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f637, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f638, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f639, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f63a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f63b, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f63c, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f63d, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f63e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f63f, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f640, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f641, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f642, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f643, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f644, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f645, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f646, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f647, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f648, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f649, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f64a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f64b, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f64c, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f64d, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f64e, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f64f, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f680, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f681, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f682, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f683, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f684, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f685, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f686, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f687, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f688, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f689, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f68a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f68b, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f68c, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f68d, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f68e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f68f, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f690, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f691, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f692, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f693, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f694, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f695, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f696, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f697, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f698, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f699, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f69a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f69b, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f69c, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f69d, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f69e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f69f, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6a0, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6a1, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6a2, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6a3, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6a4, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6a5, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6a6, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6a7, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6a8, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6a9, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6aa, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6ab, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6ac, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6ad, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6ae, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6af, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6b0, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6b1, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6b2, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6b3, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6b4, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6b5, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6b6, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6b7, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6b8, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6b9, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6ba, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6bb, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6bc, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6bd, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6be, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6bf, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6c0, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6c1, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6c2, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6c3, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6c4, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6c5, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6cb, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f6cc, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6cd, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f6ce, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f6cf, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f6d0, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6d1, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6d2, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6d5, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6d6, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6d7, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6d8, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6dc, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6dd, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6de, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6df, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6e0, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f6e1, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f6e2, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f6e3, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f6e4, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f6e5, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f6e9, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f6eb, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6ec, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6f0, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f6f3, emoji_property_emoji|emoji_property_extended_pictographic},
{0x1f6f4, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6f5, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6f6, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6f7, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6f8, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6f9, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6fa, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6fb, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f6fc, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f7e0, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f7e1, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f7e2, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f7e3, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f7e4, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f7e5, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f7e6, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f7e7, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f7e8, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f7e9, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f7ea, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f7eb, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f7f0, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f90c, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f90d, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f90e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f90f, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f910, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f911, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f912, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f913, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f914, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f915, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f916, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f917, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f918, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f919, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f91a, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f91b, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f91c, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f91d, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f91e, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f91f, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f920, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f921, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f922, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f923, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f924, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f925, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f926, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f927, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f928, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f929, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f92a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f92b, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f92c, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f92d, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f92e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f92f, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f930, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f931, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f932, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f933, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f934, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f935, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f936, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f937, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f938, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f939, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f93a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f93c, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f93d, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f93e, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f93f, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f940, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f941, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f942, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f943, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f944, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f945, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f947, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f948, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f949, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f94a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f94b, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f94c, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f94d, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f94e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f94f, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f950, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f951, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f952, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f953, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f954, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f955, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f956, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f957, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f958, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f959, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f95a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f95b, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f95c, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f95d, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f95e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f95f, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f960, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f961, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f962, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f963, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f964, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f965, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f966, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f967, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f968, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f969, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f96a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f96b, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f96c, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f96d, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f96e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f96f, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f970, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f971, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f972, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f973, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f974, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f975, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f976, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f977, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f978, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f979, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f97a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f97b, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f97c, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f97d, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f97e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f97f, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f980, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f981, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f982, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f983, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f984, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f985, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f986, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f987, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f988, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f989, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f98a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f98b, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f98c, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f98d, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f98e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f98f, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f990, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f991, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f992, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f993, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f994, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f995, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f996, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f997, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f998, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f999, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f99a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f99b, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f99c, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f99d, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f99e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f99f, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9a0, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9a1, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9a2, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9a3, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9a4, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9a5, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9a6, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9a7, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9a8, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9a9, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9aa, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9ab, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9ac, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9ad, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9ae, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9af, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9b0, emoji_property_emoji|emoji_property_emoji_component|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9b1, emoji_property_emoji|emoji_property_emoji_component|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9b2, emoji_property_emoji|emoji_property_emoji_component|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9b3, emoji_property_emoji|emoji_property_emoji_component|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9b4, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9b5, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9b6, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9b7, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9b8, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9b9, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9ba, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9bb, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9bc, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9bd, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9be, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9bf, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9c0, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9c1, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9c2, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9c3, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9c4, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9c5, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9c6, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9c7, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9c8, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9c9, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9ca, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9cb, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9cc, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9cd, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9ce, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9cf, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9d0, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9d1, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9d2, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9d3, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9d4, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9d5, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9d6, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9d7, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9d8, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9d9, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9da, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9db, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9dc, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9dd, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9de, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9df, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9e0, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9e1, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9e2, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9e3, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9e4, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9e5, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9e6, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9e7, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9e8, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9e9, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9ea, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9eb, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9ec, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9ed, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9ee, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9ef, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9f0, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9f1, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9f2, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9f3, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9f4, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9f5, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9f6, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9f7, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9f8, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9f9, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9fa, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9fb, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9fc, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9fd, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9fe, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1f9ff, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa70, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa71, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa72, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa73, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa74, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa75, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa76, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa77, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa78, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa79, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa7a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa7b, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa7c, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa80, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa81, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa82, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa83, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa84, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa85, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa86, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa87, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa88, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa89, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa8a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa8e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa8f, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa90, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa91, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa92, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa93, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa94, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa95, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa96, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa97, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa98, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa99, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa9a, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa9b, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa9c, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa9d, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa9e, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fa9f, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1faa0, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1faa1, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1faa2, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1faa3, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1faa4, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1faa5, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1faa6, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1faa7, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1faa8, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1faa9, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1faaa, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1faab, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1faac, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1faad, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1faae, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1faaf, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fab0, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fab1, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fab2, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fab3, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fab4, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fab5, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fab6, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fab7, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fab8, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fab9, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1faba, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fabb, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fabc, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fabd, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fabe, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fabf, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fac0, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fac1, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fac2, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fac3, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fac4, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fac5, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fac6, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fac8, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1facd, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1face, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1facf, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fad0, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fad1, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fad2, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fad3, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fad4, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fad5, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fad6, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fad7, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fad8, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fad9, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fada, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fadb, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fadc, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fadf, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fae0, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fae1, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fae2, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fae3, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fae4, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fae5, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fae6, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fae7, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fae8, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1fae9, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1faea, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1faef, emoji_property_emoji|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1faf0, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1faf1, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1faf2, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1faf3, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1faf4, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1faf5, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1faf6, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1faf7, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0x1faf8, emoji_property_emoji|emoji_property_emoji_modifier_base|emoji_property_emoji_presentation|emoji_property_extended_pictographic},
{0xe0020, emoji_property_emoji_component},
{0xe0021, emoji_property_emoji_component},
{0xe0022, emoji_property_emoji_component},
{0xe0023, emoji_property_emoji_component},
{0xe0024, emoji_property_emoji_component},
{0xe0025, emoji_property_emoji_component},
{0xe0026, emoji_property_emoji_component},
{0xe0027, emoji_property_emoji_component},
{0xe0028, emoji_property_emoji_component},
{0xe0029, emoji_property_emoji_component},
{0xe002a, emoji_property_emoji_component},
{0xe002b, emoji_property_emoji_component},
{0xe002c, emoji_property_emoji_component},
{0xe002d, emoji_property_emoji_component},
{0xe002e, emoji_property_emoji_component},
{0xe002f, emoji_property_emoji_component},
{0xe0030, emoji_property_emoji_component},
{0xe0031, emoji_property_emoji_component},
{0xe0032, emoji_property_emoji_component},
{0xe0033, emoji_property_emoji_component},
{0xe0034, emoji_property_emoji_component},
{0xe0035, emoji_property_emoji_component},
{0xe0036, emoji_property_emoji_component},
{0xe0037, emoji_property_emoji_component},
{0xe0038, emoji_property_emoji_component},
{0xe0039, emoji_property_emoji_component},
{0xe003a, emoji_property_emoji_component},
{0xe003b, emoji_property_emoji_component},
{0xe003c, emoji_property_emoji_component},
{0xe003d, emoji_property_emoji_component},
{0xe003e, emoji_property_emoji_component},
{0xe003f, emoji_property_emoji_component},
{0xe0040, emoji_property_emoji_component},
{0xe0041, emoji_property_emoji_component},
{0xe0042, emoji_property_emoji_component},
{0xe0043, emoji_property_emoji_component},
{0xe0044, emoji_property_emoji_component},
{0xe0045, emoji_property_emoji_component},
{0xe0046, emoji_property_emoji_component},
{0xe0047, emoji_property_emoji_component},
{0xe0048, emoji_property_emoji_component},
{0xe0049, emoji_property_emoji_component},
{0xe004a, emoji_property_emoji_component},
{0xe004b, emoji_property_emoji_component},
{0xe004c, emoji_property_emoji_component},
{0xe004d, emoji_property_emoji_component},
{0xe004e, emoji_property_emoji_component},
{0xe004f, emoji_property_emoji_component},
{0xe0050, emoji_property_emoji_component},
{0xe0051, emoji_property_emoji_component},
{0xe0052, emoji_property_emoji_component},
{0xe0053, emoji_property_emoji_component},
{0xe0054, emoji_property_emoji_component},
{0xe0055, emoji_property_emoji_component},
{0xe0056, emoji_property_emoji_component},
{0xe0057, emoji_property_emoji_component},
{0xe0058, emoji_property_emoji_component},
{0xe0059, emoji_property_emoji_component},
{0xe005a, emoji_property_emoji_component},
{0xe005b, emoji_property_emoji_component},
{0xe005c, emoji_property_emoji_component},
{0xe005d, emoji_property_emoji_component},
{0xe005e, emoji_property_emoji_component},
{0xe005f, emoji_property_emoji_component},
{0xe0060, emoji_property_emoji_component},
{0xe0061, emoji_property_emoji_component},
{0xe0062, emoji_property_emoji_component},
{0xe0063, emoji_property_emoji_component},
{0xe0064, emoji_property_emoji_component},
{0xe0065, emoji_property_emoji_component},
{0xe0066, emoji_property_emoji_component},
{0xe0067, emoji_property_emoji_component},
{0xe0068, emoji_property_emoji_component},
{0xe0069, emoji_property_emoji_component},
{0xe006a, emoji_property_emoji_component},
{0xe006b, emoji_property_emoji_component},
{0xe006c, emoji_property_emoji_component},
{0xe006d, emoji_property_emoji_component},
{0xe006e, emoji_property_emoji_component},
{0xe006f, emoji_property_emoji_component},
{0xe0070, emoji_property_emoji_component},
{0xe0071, emoji_property_emoji_component},
{0xe0072, emoji_property_emoji_component},
{0xe0073, emoji_property_emoji_component},
{0xe0074, emoji_property_emoji_component},
{0xe0075, emoji_property_emoji_component},
{0xe0076, emoji_property_emoji_component},
{0xe0077, emoji_property_emoji_component},
{0xe0078, emoji_property_emoji_component},
{0xe0079, emoji_property_emoji_component},
{0xe007a, emoji_property_emoji_component},
{0xe007b, emoji_property_emoji_component},
{0xe007c, emoji_property_emoji_component},
{0xe007d, emoji_property_emoji_component},
{0xe007e, emoji_property_emoji_component},
{0xe007f, emoji_property_emoji_component}};

const unsigned int num_emoji_chars=1537;
